@@ -166,19 +166,26 @@ def test_dkistdc_drawer_with_darks(general_cs):
         np.testing.assert_array_equal(D[np.unravel_index(i, D.shape)], cc)
 
 
-def test_dkistdc_drawer_I_trend(general_cs):
+@pytest.mark.parametrize(
+    "remove_I_trend",
+    [pytest.param(True, id="Remove I trend"), pytest.param(False, id="Don't remove I trend")],
+)
+def test_dkistdc_drawer_I_trend_and_I_clear(general_cs, remove_I_trend):
     """
     Given: a dictionary of FitsAccess objects corresponding to a set of reduced polcal data
     When: initializing a Drawer with that dictionary and fitting the trend in I_sys
     Then: the I_sys trend is fit correctly
     """
     cs_step_obj_dict = general_cs[0]
-    D = Drawer(cs_step_obj_dict, remove_I_trend=True)
+    D = Drawer(cs_step_obj_dict, remove_I_trend=remove_I_trend)
+
+    expected_trend = np.poly1d([13.98, 0.9708])
+    if not remove_I_trend:
+        expected_trend = np.poly1d([0.0, 1.0])
+
     assert D.shape == (3, 4, 1)
-    cc = np.ones((3, 5)) * np.arange(1, 6)[None, :] + 100 * np.arange(3)[:, None]
-    cc /= np.arange(1, 6) * 0.00970874 + 0.97087379
-    for i in range(np.prod(D.shape)):
-        np.testing.assert_allclose(D[np.unravel_index(i, D.shape)], cc)
+    np.testing.assert_allclose(D.norm_func, expected_trend, atol=1e-4, rtol=1e-4)
+    assert D.I_clear == 103.0
 
 
 def test_dkistdc_drawer_low_flux(cs_with_low_flux):
